==> qtjambi-webenginecore-6.2.3-sources.jar: io/qt/webengine/core/QtJambi_LibraryUtilities.java <==
package io.qt.webengine.core;

final class QtJambi_LibraryUtilities {
    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("opengl32sw"))
                io.qt.QtUtilities.loadUtilityLibrary("opengl32sw");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("d3dcompiler_47"))
                io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47");
            io.qt.QtUtilities.loadQtLibrary("OpenGL");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("Qml");
            if(io.qt.QtUtilities.isAvailableQtLibrary("DBus"))
                io.qt.QtUtilities.loadQtLibrary("DBus");
            io.qt.QtUtilities.loadQtLibrary("QmlModels");
            io.qt.QtUtilities.loadQtLibrary("Quick");
            io.qt.QtUtilities.loadQtLibrary("WebChannel");
            io.qt.QtUtilities.loadQtLibrary("Positioning");
            io.qt.QtUtilities.loadQtLibrary("WebEngineCore");
            io.qt.QtUtilities.loadQtJambiLibrary("WebEngineCore");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
    }

    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-webenginecore-6.2.4-sources.jar: io/qt/webengine/core/QtJambi_LibraryUtilities.java <==
package io.qt.webengine.core;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 2;

    final static int qtJambiPatch = 4;

    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("Gui");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libGLESv2"))
                io.qt.QtUtilities.loadUtilityLibrary("libGLESv2");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("libEGL"))
                io.qt.QtUtilities.loadUtilityLibrary("libEGL");
            if(io.qt.QtUtilities.isAvailableQtLibrary("ANGLE"))
                io.qt.QtUtilities.loadQtLibrary("ANGLE");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("opengl32sw"))
                io.qt.QtUtilities.loadUtilityLibrary("opengl32sw");
            if(io.qt.QtUtilities.isAvailableUtilityLibrary("d3dcompiler_47"))
                io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47");
            io.qt.QtUtilities.loadQtLibrary("OpenGL");
            io.qt.QtUtilities.loadQtLibrary("Network");
            io.qt.QtUtilities.loadQtLibrary("Qml");
            if(io.qt.QtUtilities.isAvailableQtLibrary("DBus"))
                io.qt.QtUtilities.loadQtLibrary("DBus");
            io.qt.QtUtilities.loadQtLibrary("QmlModels");
            io.qt.QtUtilities.loadQtLibrary("Quick");
            io.qt.QtUtilities.loadQtLibrary("WebChannel");
            io.qt.QtUtilities.loadQtLibrary("Positioning");
            io.qt.QtUtilities.loadQtLibrary("WebEngineCore");
            io.qt.QtUtilities.loadQtJambiLibrary("WebEngineCore");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
    }
    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
